@@ -21,13 +21,12 @@
  */
 
 #include <config.h>
-#include <gnome.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <libgnome/gnome-help.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include "actions.h"
 #include "dlg-add-files.h"
 #include "dlg-add-folder.h"
@@ -114,7 +113,7 @@ get_full_path (GtkWidget *file_sel)
 	if (idx > 0) {
 		const char *path_ext = fr_archive_utils__get_file_name_ext (path);
 		char       *default_ext = file_type_desc[save_type[idx-1]].ext;
-		if (strcmp_null_tollerant (path_ext, default_ext) != 0) {
+		if (strcmp_null_tolerant (path_ext, default_ext) != 0) {
 			full_path = g_strconcat (path, default_ext, NULL);
 			g_free (path);
 		}
@@ -283,19 +282,24 @@ filetype_combobox_changed_cb (GtkComboBox *combo_box,
 	int         idx;
 	const char *filename;
 	const char *ext, *newext;
+	char       *escaped_uri;
+	char       *unescaped_uri;	
 	char       *new_filename, *filename_noext;
 
 	idx = gtk_combo_box_get_active (combo_box) - 1;
 	if (idx < 0)
 		return;
 
-	filename = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (file_sel));
-	if (filename == NULL)
+	escaped_uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (file_sel));
+	if (escaped_uri == NULL)
 		return;
 
-	filename = file_name_from_path (filename);
-	if (filename == NULL)
+	unescaped_uri = gnome_vfs_format_uri_for_display (escaped_uri);
+	filename = file_name_from_path (unescaped_uri);
+	if (filename == NULL) {
+		g_free (unescaped_uri);
 		return;
+	}
 
 	ext = fr_archive_utils__get_file_name_ext (filename);
 	if (ext == NULL)
@@ -309,6 +313,7 @@ filetype_combobox_changed_cb (GtkComboBox *combo_box,
 
 	g_free (new_filename);
 	g_free (filename_noext);
+	g_free (unescaped_uri);
 }
 
 
@@ -546,6 +551,8 @@ activate_action_save_as (GtkAction *action,
 	GtkWidget     *combo_box;
 	GtkFileFilter *filter;
 	int            i;
+	const char    *escaped_uri = NULL;
+	char          *unescaped_uri = NULL;
 
 	file_sel = gtk_file_chooser_dialog_new (_("Save"),
 						GTK_WINDOW (window),
@@ -558,8 +565,12 @@ activate_action_save_as (GtkAction *action,
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), FALSE);
 	gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (file_sel), fr_window_get_open_default_dir (window));
 
-	if (fr_window_get_archive_uri (window))
-		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (file_sel), file_name_from_path (fr_window_get_archive_uri (window)));
+	if (fr_window_get_archive_uri (window)) {
+		escaped_uri = fr_window_get_archive_uri (window);
+		unescaped_uri = gnome_vfs_format_uri_for_display (escaped_uri);
+		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (file_sel), file_name_from_path (unescaped_uri));
+		g_free (unescaped_uri);
+	}
 
 	filter = gtk_file_filter_new ();
 	gtk_file_filter_set_name (filter, _("All archives"));
@@ -668,11 +679,19 @@ activate_action_extract (GtkAction *action,
 }
 
 
+void
+activate_action_extract_folder_from_sidebar (GtkAction *action,
+			 		     gpointer   data)
+{
+	dlg_extract_folder_from_sidebar (NULL, data);
+}
+
+
 void
 activate_action_copy (GtkAction *action,
 		      gpointer   data)
 {
-	fr_window_copy_selection ((FrWindow*) data);
+	fr_window_copy_selection ((FrWindow*) data, FALSE);
 }
 
 
@@ -680,7 +699,7 @@ void
 activate_action_cut (GtkAction *action,
 		     gpointer   data)
 {
-	fr_window_cut_selection ((FrWindow*) data);
+	fr_window_cut_selection ((FrWindow*) data, FALSE);
 }
 
 
@@ -688,7 +707,7 @@ void
 activate_action_paste (GtkAction *action,
 		       gpointer   data)
 {
-	fr_window_paste_selection ((FrWindow*) data);
+	fr_window_paste_selection ((FrWindow*) data, FALSE);
 }
 
 
@@ -696,7 +715,7 @@ void
 activate_action_rename (GtkAction *action,
 			gpointer   data)
 {
-	fr_window_rename_selection ((FrWindow*) data);
+	fr_window_rename_selection ((FrWindow*) data, FALSE);
 }
 
 
@@ -708,6 +727,46 @@ activate_action_delete (GtkAction *action,
 }
 
 
+void
+activate_action_copy_folder_from_sidebar (GtkAction *action,
+		      			  gpointer   data)
+{
+	fr_window_copy_selection ((FrWindow*) data, TRUE);
+}
+
+
+void
+activate_action_cut_folder_from_sidebar (GtkAction *action,
+		     			 gpointer   data)
+{
+	fr_window_cut_selection ((FrWindow*) data, TRUE);
+}
+
+
+void
+activate_action_paste_folder_from_sidebar (GtkAction *action,
+		       			   gpointer   data)
+{
+	fr_window_paste_selection ((FrWindow*) data, TRUE);
+}
+
+
+void
+activate_action_rename_folder_from_sidebar (GtkAction *action,
+					    gpointer   data)
+{
+	fr_window_rename_selection ((FrWindow*) data, TRUE);
+}
+
+
+void
+activate_action_delete_folder_from_sidebar (GtkAction *action,
+					    gpointer   data)
+{
+	dlg_delete_from_sidebar (NULL, data);
+}
+
+
 void
 activate_action_select_all (GtkAction *action,
 			    gpointer   data)
@@ -746,7 +805,7 @@ activate_action_view_or_open (GtkAction *action,
 	file_list = fr_window_get_file_list_selection (window, FALSE, NULL);
 	if (file_list == NULL)
 		return;
-	fr_window_view_or_open_file (window, (char*) file_list->data);
+	fr_window_open_files (window, file_list, FALSE);
 	path_list_free (file_list);
 }
 
@@ -756,7 +815,16 @@ activate_action_open_folder (GtkAction *action,
 			     gpointer   data)
 {
 	FrWindow *window = data;
-	fr_window_current_folder_activated (window);
+	fr_window_current_folder_activated (window, FALSE);
+}
+
+
+void
+activate_action_open_folder_from_sidebar (GtkAction *action,
+			                  gpointer   data)
+{
+	FrWindow *window = data;
+	fr_window_current_folder_activated (window, TRUE);
 }
 
 
@@ -784,6 +852,14 @@ activate_action_view_statusbar (GtkAction *action,
 }
 
 
+void
+activate_action_view_folders (GtkAction *action,
+				gpointer   data)
+{
+	eel_gconf_set_boolean (PREF_UI_FOLDERS, gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)));
+}
+
+
 void
 activate_action_stop (GtkAction *action,
 		      gpointer   data)
@@ -827,26 +903,8 @@ activate_action_manual (GtkAction *action,
 			gpointer   data)
 {
 	FrWindow *window = data;
-	GError   *err;
 
-	err = NULL;
-	gnome_help_display ("file-roller", NULL, &err);
-
-	if (err != NULL) {
-		GtkWidget *dialog;
-
-		dialog = _gtk_error_dialog_new (GTK_WINDOW (window),
-						GTK_DIALOG_DESTROY_WITH_PARENT,
-						NULL,
-						_("Could not display help"),
-						err->message);
-		g_signal_connect (G_OBJECT (dialog), "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  NULL);
-		gtk_widget_show (dialog);
-
-		g_error_free (err);
-	}
+	show_help_dialog (GTK_WINDOW (window) , NULL);
 }
 
 
