@@ -30,7 +30,7 @@
 #include "file-list.h"
 #include "fr-archive.h"
 
-#define GCONF_NOTIFICATIONS 9
+#define GCONF_NOTIFICATIONS 10
 
 enum {
 	COLUMN_FILE_DATA,
@@ -44,6 +44,14 @@ enum {
 	NUMBER_OF_COLUMNS
 };
 
+enum {
+	TREE_COLUMN_PATH,
+	TREE_COLUMN_ICON,
+	TREE_COLUMN_NAME,
+	TREE_COLUMN_WEIGHT,
+	TREE_NUMBER_OF_COLUMNS
+};
+
 typedef enum {
 	FR_BATCH_ACTION_NONE,
 	FR_BATCH_ACTION_LOAD,
@@ -54,7 +62,7 @@ typedef enum {
 	FR_BATCH_ACTION_EXTRACT_INTERACT,
 	FR_BATCH_ACTION_RENAME,
 	FR_BATCH_ACTION_PASTE,
-	FR_BATCH_ACTION_VIEW,
+	FR_BATCH_ACTION_OPEN_FILES,
 	FR_BATCH_ACTION_SAVE_AS,
 	FR_BATCH_ACTION_TEST,
 	FR_BATCH_ACTION_CLOSE,
@@ -170,18 +178,19 @@ void        fr_window_view_folder_after_extract (FrWindow      *window,
 /**/
 
 void       fr_window_go_to_location             (FrWindow       *window,
-					 	 const char     *path);
+					 	 const char     *path,
+					 	 gboolean        force_update);
 const char*fr_window_get_current_location       (FrWindow       *window);
 void       fr_window_go_up_one_level            (FrWindow       *window);
 void       fr_window_go_back                    (FrWindow       *window);
 void       fr_window_go_forward                 (FrWindow       *window);
-void       fr_window_current_folder_activated   (FrWindow       *window);
+void       fr_window_current_folder_activated   (FrWindow       *window,
+						 gboolean        from_sidebar);
 void       fr_window_set_list_mode              (FrWindow       *window,
 						 FRWindowListMode  list_mode);
 
 /**/
 
-void       fr_window_update_file_list             (FrWindow    *window);
 void       fr_window_update_list_order            (FrWindow    *window);
 GList *    fr_window_get_file_list_selection      (FrWindow    *window,
 						   gboolean     recursive,
@@ -192,6 +201,12 @@ GList *    fr_window_get_file_list_from_path_list (FrWindow    *window,
 GList *    fr_window_get_file_list_pattern        (FrWindow    *window,
 						   const char  *pattern);
 int        fr_window_get_n_selected_files         (FrWindow    *window);
+GList *    fr_window_get_folder_tree_selection    (FrWindow    *window,
+				     		   gboolean     recursive,
+				     		   gboolean    *has_dirs);
+GList *    fr_window_get_selection                (FrWindow    *window,
+		  	 			   gboolean     from_sidebar,
+		  	 			   char       **return_base_dir);				     		   
 GtkListStore *
 	   fr_window_get_list_store               (FrWindow    *window);
 void       fr_window_select_all                   (FrWindow    *window);
@@ -201,10 +216,14 @@ void       fr_window_set_sort_type                (FrWindow    *window,
 
 /**/
 
-void       fr_window_rename_selection             (FrWindow    *window);
-void       fr_window_cut_selection                (FrWindow    *window);
-void       fr_window_copy_selection               (FrWindow    *window);
-void       fr_window_paste_selection              (FrWindow    *window);
+void       fr_window_rename_selection             (FrWindow    *window,
+						   gboolean     from_sidebar);
+void       fr_window_cut_selection                (FrWindow    *window,
+						   gboolean     from_sidebar);
+void       fr_window_copy_selection               (FrWindow    *window,
+						   gboolean     from_sidebar);
+void       fr_window_paste_selection              (FrWindow    *window,
+						   gboolean     from_sidebar);
 
 /**/
 
@@ -216,16 +235,18 @@ void       fr_window_stop_activity_mode           (FrWindow    *window);
 
 void        fr_window_view_last_output            (FrWindow   *window,
 						   const char *title);
-void        fr_window_view_file                   (FrWindow   *window,
-						   char       *file);
+
 void        fr_window_open_files                  (FrWindow   *window,
+						   GList      *file_list,
+						   gboolean    ask_application);
+void        fr_window_open_files_with_command     (FrWindow   *window,
 						   GList      *file_list,
 						   char       *command);
 void        fr_window_open_files_with_application (FrWindow   *window,
 						   GList      *file_list,
 						   GnomeVFSMimeApplication *app);
-void        fr_window_view_or_open_file           (FrWindow   *window,
-						   char       *file);
+void        fr_window_update_files                (FrWindow   *window,
+						   GList      *file_list);			   
 void        fr_window_update_columns_visibility   (FrWindow   *window);
 void        fr_window_update_history_list         (FrWindow   *window);
 void        fr_window_set_default_dir             (FrWindow   *window,
@@ -248,6 +269,8 @@ void        fr_window_set_toolbar_visibility      (FrWindow   *window,
 						   gboolean    value);
 void        fr_window_set_statusbar_visibility    (FrWindow   *window,
 						   gboolean    value);
+void        fr_window_set_folders_visibility      (FrWindow   *window,
+						   gboolean    value);
 
 /* batch mode procedures. */
 
@@ -270,8 +293,7 @@ void       fr_window_set_batch__extract           (FrWindow      *window,
 						   const char    *filename,
 						   const char    *dest_dir);
 void       fr_window_set_batch__extract_here      (FrWindow      *window,
-						   const char    *filename,
-						   const char    *dest_dir);
+						   const char    *filename);
 void       fr_window_set_batch__add               (FrWindow      *window,
 						   const char    *archive,
 						   GList         *file_list);
@@ -284,4 +306,6 @@ gboolean   fr_window_file_list_drag_data_get (FrWindow         *window,
 					      GtkSelectionData *selection_data,
 					      GList            *path_list);
 
+void       fr_window_update_dialog_closed    (FrWindow *window); 
+
 #endif /* FR_WINDOW_H */
